@@ -9,7 +9,7 @@ except ModuleNotFoundError:  # pragma: no cover
 
 __version__ = importlib_metadata.version(__name__)
 
-from .utilities import jit, guvectorize
+from .utilities import jit, guvectorize, float64, boolean
 from . import algebra, properties, converters, distance, utilities
 
 algebra_ufuncs = type('AlgebraUfuncs', (object,), dict())()
