@@ -2,17 +2,14 @@
 # See LICENSE file for details:
 # <https://github.com/moble/quaternionic/blob/master/LICENSE>
 
+import sys
 import functools
-import numba
 
 ufunc_attributes = [
     'nin', 'nout', 'nargs', 'ntypes', 'types', 'identity', 'signature',
     'reduce', 'accumulate', 'reduceat', 'outer', 'at'
 ]
 
-jit = functools.partial(numba.njit, cache=True)
-guvectorize = functools.partial(numba.guvectorize, nopython=True, cache=True)
-
 
 def type_self_return(f):
     """Decorate jitted functions to return with type of first argument"""
@@ -133,7 +130,6 @@ def pyguvectorize(types, signature):
     """
     import functools
     import numpy as np
-    import numba as nb
     inputs, output = signature.split('->')
     inputs = inputs.split(',')
     slice_a = slice(None) if inputs[0]=='()' else 0
@@ -196,3 +192,23 @@ def pyguvectorize_module_functions(module, obj):
         if isinstance(v, types.FunctionType) and hasattr(v, 'types') and hasattr(v, 'signature'):
             v_ufunc = pyguvectorize(v.types, v.signature)(v)
             setattr(obj, k, v_ufunc)
+
+
+if sys.implementation.name.lower() == 'pypy':  # pragma: no cover
+    class _FakeNumbaType(object):
+        def __init__(self, name):
+            self.name = name
+        @property
+        def dtype(self):
+            return self
+        def __getitem__(self, *args, **kwargs):
+            return self
+    float64 = _FakeNumbaType('float64')
+    boolean = _FakeNumbaType('boolean')
+    jit = lambda f: f
+    guvectorize = pyguvectorize
+else:
+    import numba
+    from numba import float64, boolean
+    jit = functools.partial(numba.njit, cache=True)
+    guvectorize = functools.partial(numba.guvectorize, nopython=True, cache=True)
